//
// MenuItem
//
// The MenuItem is just a thing that appears in a menu list.
// getTitle() - return the title or label for this item.
// getImage() - return the image for this item.
// getLink() - return the correct url for this button
// isRefresh() - return boolean whether this is the Refresh Toolbar item.
// isUninstall() - return boolean whether this is the Uninstall Companion item
//

function MenuItem(raw)
{
    this.raw = raw;
    this.menuText="";
    this.toolTip = null;
    this.menuLink= "";
    this.menuType = "";
    this.parse(this.raw);
}

MenuItem.prototype.getTitle = function()
{
    if (this.menutype == 7)
        return (this.menuText + " (Mozilla)");
    else
        return unescape(this.menuText);
}

MenuItem.prototype.getToolTip = function()
{
    return this.toolTip || this.menuText ;
}

MenuItem.prototype.getLink = function()
{
        return this.menuLink;
}

MenuItem.prototype.isRefresh = function()
{
      return (this.menutype == 6);
}

MenuItem.prototype.isAbout = function()
{
      return (this.menutype == 7);
}

MenuItem.prototype.isIconOnlyToggle = function()
{
      return (this.menutype == 14);
}

MenuItem.prototype.isPopup = function()
{
      return (this.menutype == 18);
}

MenuItem.prototype.isUninstall = function()
{
      return (this.menutype == 8);
}

MenuItem.prototype.isSwitch = function()
{
      return (this.menutype == 9);
}

MenuItem.prototype.isActionItem = function()
{
      return (this.menutype == 4);
}

MenuItem.prototype.isAddBookmark = function()
{
      return (this.menutype == 1);
}

MenuItem.prototype.isHighlight = function()
{
      return (this.menutype == 19);
}

MenuItem.prototype.isSeparator = function()
{
    if(this.menuText == "-")
        return true;
    else
        return false;
}

MenuItem.prototype.parse = function(txt)
{
    var items = txt.split('\x18');
    this.menuText = items[0]; 
    var linkRaw = items[1];
    this.menuLink = this.extractLink(linkRaw);
}

MenuItem.prototype.extractLink = function(txt)
{
    var link = "";
    var part = txt.split('\x01');
    
        // often there is a string of ^A that represent a link.
        // -A- -A- -A-
        // after 3rd \x01 is $, then link is after 4th \x01, but need to replace % with $VAR
        // VAR could be ESRV
        // after 3rd \x01 is %, then remove %, and return link.
        // Note, could be empty... not always link in there!
        //alert('find link in: ' + txt);
        
    //if(this.isAddBookmark())
    if (part.length > 1)
    {
       var type = part[1];
       this.menutype = type;
       if (part.length > 3) 
           this.menuid = part[2];
       switch (type)
        {
         case "1":        // Add Bookmark
            //alert("Building bookmark link from '"+txt+"'");
            // the bookmark should look like:
            // \x011\x01
            // \x011\x01N\x19
            // in the first case, the Folder is empty.
            // in the second, the N is the folder id
            // so we're gonna skip ahead 3 spaces, then get the next char
            // 
            // Search for a ^A followed by a number, starting after the initial '\x01,1'.
            var folder = part[2];
            if (folder)
            	link = folder;
            
            return link;
                break;
          case "9":        // Switch toolbar
            var link = part[2];
            return link;
            break;
          case "4":        // Action item
          case "14":       // Toggle Icons only 
	     var links = part.slice(3);
             link = links.join('\x01');
             return link;
             break;            
          case "18":	   // Popup window
              // The raw text contains the width and height of the popup, as well as the URL.
              // We extract them and build the argument list for window.open()
              link = "'"+part[5]+"','"+this.menuText+"','width="+part[2]+",height="+part[3]+",scrollbars=yes'";
              return link;
              break;
          case "19":      //Highlight search terms on page (unimplemented - no link)
          default:
             return link;
             break;
        }
    } else
    {    // Probably a bookmark, just extract the text
      this.menutype = 4;    // Action item
    //  var links = txt.match(/([^\x19]*)/);
      link = txt;
    return link;
    }
}

